
Generators
==========


.. automodule:: opendssdirect.Generators
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Generators.AllNames

    All generator names

.. function:: opendssdirect.Generators.Count

    Number of Generator Objects in Active Circuit

.. function:: opendssdirect.Generators.First

    Sets first Generator to be active.  Returns 0 if none.

.. function:: opendssdirect.Generators.ForcedON

    Indicates whether the generator is forced ON regardles of other dispatch criteria.Sets indication whether the generator is forced ON regardles of other dispatch criteria.

.. function:: opendssdirect.Generators.Idx

    Get/Set active Generator by index into generators list.  1..CountSet active Generator by index into generators list.  1..Count

.. function:: opendssdirect.Generators.Model

    Generator modelSet the Generator model

.. function:: opendssdirect.Generators.Name

    Active generator name.Sets a generator active by name.

.. function:: opendssdirect.Generators.Next

    Sets next Generator to be active.  Returns 0 if no more.

.. function:: opendssdirect.Generators.PF

    Power factor (pos. = producing vars)Set the power factor (pos. = producing vars)

.. function:: opendssdirect.Generators.Phases

    Number of phasesSet the number of phases

.. function:: opendssdirect.Generators.RegisterNames

    Array of Names of all generator energy meter registers

.. function:: opendssdirect.Generators.RegisterValues

    Array of valus in generator energy meter registers.

.. function:: opendssdirect.Generators.Vmaxpu

    Get the Vmaxpu for Generator Model.Set the Vmaxpu for Generator Model.

.. function:: opendssdirect.Generators.Vminpu

    Get the Vminpu for Generator Model.Set the Vminpu for Generator Model.

.. function:: opendssdirect.Generators.kV

    Voltage base for the active generator, kVSet the voltage base for the active generator, kV

.. function:: opendssdirect.Generators.kVARated

    Get the KVA rating of the generator.Set the KVA rating of the generator.

.. function:: opendssdirect.Generators.kW

    kW output for the active generator. kvar is updated for current power factor.Set the kW output for the active generator. kvar is updated for current power factor.

.. function:: opendssdirect.Generators.kvar

    kvar output for the active generator. Updates power factor based on present kW value.Set the kvar output for the active generator. Updates power factor based on present kW value.

